# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import StrictBool
from uuid import UUID
from immich.client.models.asset_order import AssetOrder
from immich.client.models.asset_visibility import AssetVisibility
from immich.client.models.time_bucket_asset_response_dto import (
    TimeBucketAssetResponseDto,
)
from immich.client.models.time_buckets_response_dto import TimeBucketsResponseDto

from immich.client.api_client import ApiClient, RequestSerialized
from immich.client.api_response import ApiResponse
from immich.client.rest import RESTResponseType


class TimelineApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_call
    async def get_time_bucket(
        self,
        time_bucket: Annotated[
            StrictStr,
            Field(
                description='Time bucket identifier in YYYY-MM-DD format (e.g., "2024-01-01" for January 2024)'
            ),
        ],
        album_id: Annotated[
            Optional[UUID],
            Field(description="Filter assets belonging to a specific album"),
        ] = None,
        is_favorite: Annotated[
            Optional[StrictBool],
            Field(
                description="Filter by favorite status (true for favorites only, false for non-favorites only)"
            ),
        ] = None,
        is_trashed: Annotated[
            Optional[StrictBool],
            Field(
                description="Filter by trash status (true for trashed assets only, false for non-trashed only)"
            ),
        ] = None,
        key: Optional[StrictStr] = None,
        order: Annotated[
            Optional[AssetOrder],
            Field(
                description="Sort order for assets within time buckets (ASC for oldest first, DESC for newest first)"
            ),
        ] = None,
        person_id: Annotated[
            Optional[UUID],
            Field(
                description="Filter assets containing a specific person (face recognition)"
            ),
        ] = None,
        slug: Optional[StrictStr] = None,
        tag_id: Annotated[
            Optional[UUID], Field(description="Filter assets with a specific tag")
        ] = None,
        user_id: Annotated[
            Optional[UUID], Field(description="Filter assets by specific user ID")
        ] = None,
        visibility: Annotated[
            Optional[AssetVisibility],
            Field(
                description="Filter by asset visibility status (ARCHIVE, TIMELINE, HIDDEN, LOCKED)"
            ),
        ] = None,
        with_coordinates: Annotated[
            Optional[StrictBool],
            Field(description="Include location data in the response"),
        ] = None,
        with_partners: Annotated[
            Optional[StrictBool], Field(description="Include assets shared by partners")
        ] = None,
        with_stacked: Annotated[
            Optional[StrictBool],
            Field(
                description="Include stacked assets in the response. When true, only primary assets from stacks are returned."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TimeBucketAssetResponseDto:
        """Get time bucket

        Retrieve a string of all asset ids in a given time bucket.

        :param time_bucket: Time bucket identifier in YYYY-MM-DD format (e.g., \"2024-01-01\" for January 2024) (required)
        :type time_bucket: str
        :param album_id: Filter assets belonging to a specific album
        :type album_id: UUID
        :param is_favorite: Filter by favorite status (true for favorites only, false for non-favorites only)
        :type is_favorite: bool
        :param is_trashed: Filter by trash status (true for trashed assets only, false for non-trashed only)
        :type is_trashed: bool
        :param key:
        :type key: str
        :param order: Sort order for assets within time buckets (ASC for oldest first, DESC for newest first)
        :type order: AssetOrder
        :param person_id: Filter assets containing a specific person (face recognition)
        :type person_id: UUID
        :param slug:
        :type slug: str
        :param tag_id: Filter assets with a specific tag
        :type tag_id: UUID
        :param user_id: Filter assets by specific user ID
        :type user_id: UUID
        :param visibility: Filter by asset visibility status (ARCHIVE, TIMELINE, HIDDEN, LOCKED)
        :type visibility: AssetVisibility
        :param with_coordinates: Include location data in the response
        :type with_coordinates: bool
        :param with_partners: Include assets shared by partners
        :type with_partners: bool
        :param with_stacked: Include stacked assets in the response. When true, only primary assets from stacks are returned.
        :type with_stacked: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_time_bucket_serialize(
            time_bucket=time_bucket,
            album_id=album_id,
            is_favorite=is_favorite,
            is_trashed=is_trashed,
            key=key,
            order=order,
            person_id=person_id,
            slug=slug,
            tag_id=tag_id,
            user_id=user_id,
            visibility=visibility,
            with_coordinates=with_coordinates,
            with_partners=with_partners,
            with_stacked=with_stacked,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "TimeBucketAssetResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def get_time_bucket_with_http_info(
        self,
        time_bucket: Annotated[
            StrictStr,
            Field(
                description='Time bucket identifier in YYYY-MM-DD format (e.g., "2024-01-01" for January 2024)'
            ),
        ],
        album_id: Annotated[
            Optional[UUID],
            Field(description="Filter assets belonging to a specific album"),
        ] = None,
        is_favorite: Annotated[
            Optional[StrictBool],
            Field(
                description="Filter by favorite status (true for favorites only, false for non-favorites only)"
            ),
        ] = None,
        is_trashed: Annotated[
            Optional[StrictBool],
            Field(
                description="Filter by trash status (true for trashed assets only, false for non-trashed only)"
            ),
        ] = None,
        key: Optional[StrictStr] = None,
        order: Annotated[
            Optional[AssetOrder],
            Field(
                description="Sort order for assets within time buckets (ASC for oldest first, DESC for newest first)"
            ),
        ] = None,
        person_id: Annotated[
            Optional[UUID],
            Field(
                description="Filter assets containing a specific person (face recognition)"
            ),
        ] = None,
        slug: Optional[StrictStr] = None,
        tag_id: Annotated[
            Optional[UUID], Field(description="Filter assets with a specific tag")
        ] = None,
        user_id: Annotated[
            Optional[UUID], Field(description="Filter assets by specific user ID")
        ] = None,
        visibility: Annotated[
            Optional[AssetVisibility],
            Field(
                description="Filter by asset visibility status (ARCHIVE, TIMELINE, HIDDEN, LOCKED)"
            ),
        ] = None,
        with_coordinates: Annotated[
            Optional[StrictBool],
            Field(description="Include location data in the response"),
        ] = None,
        with_partners: Annotated[
            Optional[StrictBool], Field(description="Include assets shared by partners")
        ] = None,
        with_stacked: Annotated[
            Optional[StrictBool],
            Field(
                description="Include stacked assets in the response. When true, only primary assets from stacks are returned."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TimeBucketAssetResponseDto]:
        """Get time bucket

        Retrieve a string of all asset ids in a given time bucket.

        :param time_bucket: Time bucket identifier in YYYY-MM-DD format (e.g., \"2024-01-01\" for January 2024) (required)
        :type time_bucket: str
        :param album_id: Filter assets belonging to a specific album
        :type album_id: UUID
        :param is_favorite: Filter by favorite status (true for favorites only, false for non-favorites only)
        :type is_favorite: bool
        :param is_trashed: Filter by trash status (true for trashed assets only, false for non-trashed only)
        :type is_trashed: bool
        :param key:
        :type key: str
        :param order: Sort order for assets within time buckets (ASC for oldest first, DESC for newest first)
        :type order: AssetOrder
        :param person_id: Filter assets containing a specific person (face recognition)
        :type person_id: UUID
        :param slug:
        :type slug: str
        :param tag_id: Filter assets with a specific tag
        :type tag_id: UUID
        :param user_id: Filter assets by specific user ID
        :type user_id: UUID
        :param visibility: Filter by asset visibility status (ARCHIVE, TIMELINE, HIDDEN, LOCKED)
        :type visibility: AssetVisibility
        :param with_coordinates: Include location data in the response
        :type with_coordinates: bool
        :param with_partners: Include assets shared by partners
        :type with_partners: bool
        :param with_stacked: Include stacked assets in the response. When true, only primary assets from stacks are returned.
        :type with_stacked: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_time_bucket_serialize(
            time_bucket=time_bucket,
            album_id=album_id,
            is_favorite=is_favorite,
            is_trashed=is_trashed,
            key=key,
            order=order,
            person_id=person_id,
            slug=slug,
            tag_id=tag_id,
            user_id=user_id,
            visibility=visibility,
            with_coordinates=with_coordinates,
            with_partners=with_partners,
            with_stacked=with_stacked,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "TimeBucketAssetResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def get_time_bucket_without_preload_content(
        self,
        time_bucket: Annotated[
            StrictStr,
            Field(
                description='Time bucket identifier in YYYY-MM-DD format (e.g., "2024-01-01" for January 2024)'
            ),
        ],
        album_id: Annotated[
            Optional[UUID],
            Field(description="Filter assets belonging to a specific album"),
        ] = None,
        is_favorite: Annotated[
            Optional[StrictBool],
            Field(
                description="Filter by favorite status (true for favorites only, false for non-favorites only)"
            ),
        ] = None,
        is_trashed: Annotated[
            Optional[StrictBool],
            Field(
                description="Filter by trash status (true for trashed assets only, false for non-trashed only)"
            ),
        ] = None,
        key: Optional[StrictStr] = None,
        order: Annotated[
            Optional[AssetOrder],
            Field(
                description="Sort order for assets within time buckets (ASC for oldest first, DESC for newest first)"
            ),
        ] = None,
        person_id: Annotated[
            Optional[UUID],
            Field(
                description="Filter assets containing a specific person (face recognition)"
            ),
        ] = None,
        slug: Optional[StrictStr] = None,
        tag_id: Annotated[
            Optional[UUID], Field(description="Filter assets with a specific tag")
        ] = None,
        user_id: Annotated[
            Optional[UUID], Field(description="Filter assets by specific user ID")
        ] = None,
        visibility: Annotated[
            Optional[AssetVisibility],
            Field(
                description="Filter by asset visibility status (ARCHIVE, TIMELINE, HIDDEN, LOCKED)"
            ),
        ] = None,
        with_coordinates: Annotated[
            Optional[StrictBool],
            Field(description="Include location data in the response"),
        ] = None,
        with_partners: Annotated[
            Optional[StrictBool], Field(description="Include assets shared by partners")
        ] = None,
        with_stacked: Annotated[
            Optional[StrictBool],
            Field(
                description="Include stacked assets in the response. When true, only primary assets from stacks are returned."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get time bucket

        Retrieve a string of all asset ids in a given time bucket.

        :param time_bucket: Time bucket identifier in YYYY-MM-DD format (e.g., \"2024-01-01\" for January 2024) (required)
        :type time_bucket: str
        :param album_id: Filter assets belonging to a specific album
        :type album_id: UUID
        :param is_favorite: Filter by favorite status (true for favorites only, false for non-favorites only)
        :type is_favorite: bool
        :param is_trashed: Filter by trash status (true for trashed assets only, false for non-trashed only)
        :type is_trashed: bool
        :param key:
        :type key: str
        :param order: Sort order for assets within time buckets (ASC for oldest first, DESC for newest first)
        :type order: AssetOrder
        :param person_id: Filter assets containing a specific person (face recognition)
        :type person_id: UUID
        :param slug:
        :type slug: str
        :param tag_id: Filter assets with a specific tag
        :type tag_id: UUID
        :param user_id: Filter assets by specific user ID
        :type user_id: UUID
        :param visibility: Filter by asset visibility status (ARCHIVE, TIMELINE, HIDDEN, LOCKED)
        :type visibility: AssetVisibility
        :param with_coordinates: Include location data in the response
        :type with_coordinates: bool
        :param with_partners: Include assets shared by partners
        :type with_partners: bool
        :param with_stacked: Include stacked assets in the response. When true, only primary assets from stacks are returned.
        :type with_stacked: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_time_bucket_serialize(
            time_bucket=time_bucket,
            album_id=album_id,
            is_favorite=is_favorite,
            is_trashed=is_trashed,
            key=key,
            order=order,
            person_id=person_id,
            slug=slug,
            tag_id=tag_id,
            user_id=user_id,
            visibility=visibility,
            with_coordinates=with_coordinates,
            with_partners=with_partners,
            with_stacked=with_stacked,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "TimeBucketAssetResponseDto",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _get_time_bucket_serialize(
        self,
        time_bucket,
        album_id,
        is_favorite,
        is_trashed,
        key,
        order,
        person_id,
        slug,
        tag_id,
        user_id,
        visibility,
        with_coordinates,
        with_partners,
        with_stacked,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if album_id is not None:
            _query_params.append(("albumId", album_id))

        if is_favorite is not None:
            _query_params.append(("isFavorite", is_favorite))

        if is_trashed is not None:
            _query_params.append(("isTrashed", is_trashed))

        if key is not None:
            _query_params.append(("key", key))

        if order is not None:
            _query_params.append(("order", order.value))

        if person_id is not None:
            _query_params.append(("personId", person_id))

        if slug is not None:
            _query_params.append(("slug", slug))

        if tag_id is not None:
            _query_params.append(("tagId", tag_id))

        if time_bucket is not None:
            _query_params.append(("timeBucket", time_bucket))

        if user_id is not None:
            _query_params.append(("userId", user_id))

        if visibility is not None:
            _query_params.append(("visibility", visibility.value))

        if with_coordinates is not None:
            _query_params.append(("withCoordinates", with_coordinates))

        if with_partners is not None:
            _query_params.append(("withPartners", with_partners))

        if with_stacked is not None:
            _query_params.append(("withStacked", with_stacked))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["cookie", "api_key", "bearer"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/timeline/bucket",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )

    @validate_call
    async def get_time_buckets(
        self,
        album_id: Annotated[
            Optional[UUID],
            Field(description="Filter assets belonging to a specific album"),
        ] = None,
        is_favorite: Annotated[
            Optional[StrictBool],
            Field(
                description="Filter by favorite status (true for favorites only, false for non-favorites only)"
            ),
        ] = None,
        is_trashed: Annotated[
            Optional[StrictBool],
            Field(
                description="Filter by trash status (true for trashed assets only, false for non-trashed only)"
            ),
        ] = None,
        key: Optional[StrictStr] = None,
        order: Annotated[
            Optional[AssetOrder],
            Field(
                description="Sort order for assets within time buckets (ASC for oldest first, DESC for newest first)"
            ),
        ] = None,
        person_id: Annotated[
            Optional[UUID],
            Field(
                description="Filter assets containing a specific person (face recognition)"
            ),
        ] = None,
        slug: Optional[StrictStr] = None,
        tag_id: Annotated[
            Optional[UUID], Field(description="Filter assets with a specific tag")
        ] = None,
        user_id: Annotated[
            Optional[UUID], Field(description="Filter assets by specific user ID")
        ] = None,
        visibility: Annotated[
            Optional[AssetVisibility],
            Field(
                description="Filter by asset visibility status (ARCHIVE, TIMELINE, HIDDEN, LOCKED)"
            ),
        ] = None,
        with_coordinates: Annotated[
            Optional[StrictBool],
            Field(description="Include location data in the response"),
        ] = None,
        with_partners: Annotated[
            Optional[StrictBool], Field(description="Include assets shared by partners")
        ] = None,
        with_stacked: Annotated[
            Optional[StrictBool],
            Field(
                description="Include stacked assets in the response. When true, only primary assets from stacks are returned."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> List[TimeBucketsResponseDto]:
        """Get time buckets

        Retrieve a list of all minimal time buckets.

        :param album_id: Filter assets belonging to a specific album
        :type album_id: UUID
        :param is_favorite: Filter by favorite status (true for favorites only, false for non-favorites only)
        :type is_favorite: bool
        :param is_trashed: Filter by trash status (true for trashed assets only, false for non-trashed only)
        :type is_trashed: bool
        :param key:
        :type key: str
        :param order: Sort order for assets within time buckets (ASC for oldest first, DESC for newest first)
        :type order: AssetOrder
        :param person_id: Filter assets containing a specific person (face recognition)
        :type person_id: UUID
        :param slug:
        :type slug: str
        :param tag_id: Filter assets with a specific tag
        :type tag_id: UUID
        :param user_id: Filter assets by specific user ID
        :type user_id: UUID
        :param visibility: Filter by asset visibility status (ARCHIVE, TIMELINE, HIDDEN, LOCKED)
        :type visibility: AssetVisibility
        :param with_coordinates: Include location data in the response
        :type with_coordinates: bool
        :param with_partners: Include assets shared by partners
        :type with_partners: bool
        :param with_stacked: Include stacked assets in the response. When true, only primary assets from stacks are returned.
        :type with_stacked: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_time_buckets_serialize(
            album_id=album_id,
            is_favorite=is_favorite,
            is_trashed=is_trashed,
            key=key,
            order=order,
            person_id=person_id,
            slug=slug,
            tag_id=tag_id,
            user_id=user_id,
            visibility=visibility,
            with_coordinates=with_coordinates,
            with_partners=with_partners,
            with_stacked=with_stacked,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "List[TimeBucketsResponseDto]",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data

    @validate_call
    async def get_time_buckets_with_http_info(
        self,
        album_id: Annotated[
            Optional[UUID],
            Field(description="Filter assets belonging to a specific album"),
        ] = None,
        is_favorite: Annotated[
            Optional[StrictBool],
            Field(
                description="Filter by favorite status (true for favorites only, false for non-favorites only)"
            ),
        ] = None,
        is_trashed: Annotated[
            Optional[StrictBool],
            Field(
                description="Filter by trash status (true for trashed assets only, false for non-trashed only)"
            ),
        ] = None,
        key: Optional[StrictStr] = None,
        order: Annotated[
            Optional[AssetOrder],
            Field(
                description="Sort order for assets within time buckets (ASC for oldest first, DESC for newest first)"
            ),
        ] = None,
        person_id: Annotated[
            Optional[UUID],
            Field(
                description="Filter assets containing a specific person (face recognition)"
            ),
        ] = None,
        slug: Optional[StrictStr] = None,
        tag_id: Annotated[
            Optional[UUID], Field(description="Filter assets with a specific tag")
        ] = None,
        user_id: Annotated[
            Optional[UUID], Field(description="Filter assets by specific user ID")
        ] = None,
        visibility: Annotated[
            Optional[AssetVisibility],
            Field(
                description="Filter by asset visibility status (ARCHIVE, TIMELINE, HIDDEN, LOCKED)"
            ),
        ] = None,
        with_coordinates: Annotated[
            Optional[StrictBool],
            Field(description="Include location data in the response"),
        ] = None,
        with_partners: Annotated[
            Optional[StrictBool], Field(description="Include assets shared by partners")
        ] = None,
        with_stacked: Annotated[
            Optional[StrictBool],
            Field(
                description="Include stacked assets in the response. When true, only primary assets from stacks are returned."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[List[TimeBucketsResponseDto]]:
        """Get time buckets

        Retrieve a list of all minimal time buckets.

        :param album_id: Filter assets belonging to a specific album
        :type album_id: UUID
        :param is_favorite: Filter by favorite status (true for favorites only, false for non-favorites only)
        :type is_favorite: bool
        :param is_trashed: Filter by trash status (true for trashed assets only, false for non-trashed only)
        :type is_trashed: bool
        :param key:
        :type key: str
        :param order: Sort order for assets within time buckets (ASC for oldest first, DESC for newest first)
        :type order: AssetOrder
        :param person_id: Filter assets containing a specific person (face recognition)
        :type person_id: UUID
        :param slug:
        :type slug: str
        :param tag_id: Filter assets with a specific tag
        :type tag_id: UUID
        :param user_id: Filter assets by specific user ID
        :type user_id: UUID
        :param visibility: Filter by asset visibility status (ARCHIVE, TIMELINE, HIDDEN, LOCKED)
        :type visibility: AssetVisibility
        :param with_coordinates: Include location data in the response
        :type with_coordinates: bool
        :param with_partners: Include assets shared by partners
        :type with_partners: bool
        :param with_stacked: Include stacked assets in the response. When true, only primary assets from stacks are returned.
        :type with_stacked: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_time_buckets_serialize(
            album_id=album_id,
            is_favorite=is_favorite,
            is_trashed=is_trashed,
            key=key,
            order=order,
            person_id=person_id,
            slug=slug,
            tag_id=tag_id,
            user_id=user_id,
            visibility=visibility,
            with_coordinates=with_coordinates,
            with_partners=with_partners,
            with_stacked=with_stacked,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "List[TimeBucketsResponseDto]",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        await response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )

    @validate_call
    async def get_time_buckets_without_preload_content(
        self,
        album_id: Annotated[
            Optional[UUID],
            Field(description="Filter assets belonging to a specific album"),
        ] = None,
        is_favorite: Annotated[
            Optional[StrictBool],
            Field(
                description="Filter by favorite status (true for favorites only, false for non-favorites only)"
            ),
        ] = None,
        is_trashed: Annotated[
            Optional[StrictBool],
            Field(
                description="Filter by trash status (true for trashed assets only, false for non-trashed only)"
            ),
        ] = None,
        key: Optional[StrictStr] = None,
        order: Annotated[
            Optional[AssetOrder],
            Field(
                description="Sort order for assets within time buckets (ASC for oldest first, DESC for newest first)"
            ),
        ] = None,
        person_id: Annotated[
            Optional[UUID],
            Field(
                description="Filter assets containing a specific person (face recognition)"
            ),
        ] = None,
        slug: Optional[StrictStr] = None,
        tag_id: Annotated[
            Optional[UUID], Field(description="Filter assets with a specific tag")
        ] = None,
        user_id: Annotated[
            Optional[UUID], Field(description="Filter assets by specific user ID")
        ] = None,
        visibility: Annotated[
            Optional[AssetVisibility],
            Field(
                description="Filter by asset visibility status (ARCHIVE, TIMELINE, HIDDEN, LOCKED)"
            ),
        ] = None,
        with_coordinates: Annotated[
            Optional[StrictBool],
            Field(description="Include location data in the response"),
        ] = None,
        with_partners: Annotated[
            Optional[StrictBool], Field(description="Include assets shared by partners")
        ] = None,
        with_stacked: Annotated[
            Optional[StrictBool],
            Field(
                description="Include stacked assets in the response. When true, only primary assets from stacks are returned."
            ),
        ] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)], Annotated[StrictFloat, Field(gt=0)]
            ],
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get time buckets

        Retrieve a list of all minimal time buckets.

        :param album_id: Filter assets belonging to a specific album
        :type album_id: UUID
        :param is_favorite: Filter by favorite status (true for favorites only, false for non-favorites only)
        :type is_favorite: bool
        :param is_trashed: Filter by trash status (true for trashed assets only, false for non-trashed only)
        :type is_trashed: bool
        :param key:
        :type key: str
        :param order: Sort order for assets within time buckets (ASC for oldest first, DESC for newest first)
        :type order: AssetOrder
        :param person_id: Filter assets containing a specific person (face recognition)
        :type person_id: UUID
        :param slug:
        :type slug: str
        :param tag_id: Filter assets with a specific tag
        :type tag_id: UUID
        :param user_id: Filter assets by specific user ID
        :type user_id: UUID
        :param visibility: Filter by asset visibility status (ARCHIVE, TIMELINE, HIDDEN, LOCKED)
        :type visibility: AssetVisibility
        :param with_coordinates: Include location data in the response
        :type with_coordinates: bool
        :param with_partners: Include assets shared by partners
        :type with_partners: bool
        :param with_stacked: Include stacked assets in the response. When true, only primary assets from stacks are returned.
        :type with_stacked: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """  # noqa: E501

        _param = self._get_time_buckets_serialize(
            album_id=album_id,
            is_favorite=is_favorite,
            is_trashed=is_trashed,
            key=key,
            order=order,
            person_id=person_id,
            slug=slug,
            tag_id=tag_id,
            user_id=user_id,
            visibility=visibility,
            with_coordinates=with_coordinates,
            with_partners=with_partners,
            with_stacked=with_stacked,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index,
        )

        _response_types_map: Dict[str, Optional[str]] = {
            "200": "List[TimeBucketsResponseDto]",
        }
        response_data = await self.api_client.call_api(
            *_param, _request_timeout=_request_timeout
        )
        return response_data.response

    def _get_time_buckets_serialize(
        self,
        album_id,
        is_favorite,
        is_trashed,
        key,
        order,
        person_id,
        slug,
        tag_id,
        user_id,
        visibility,
        with_coordinates,
        with_partners,
        with_stacked,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:
        _host = None

        _collection_formats: Dict[str, str] = {}

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if album_id is not None:
            _query_params.append(("albumId", album_id))

        if is_favorite is not None:
            _query_params.append(("isFavorite", is_favorite))

        if is_trashed is not None:
            _query_params.append(("isTrashed", is_trashed))

        if key is not None:
            _query_params.append(("key", key))

        if order is not None:
            _query_params.append(("order", order.value))

        if person_id is not None:
            _query_params.append(("personId", person_id))

        if slug is not None:
            _query_params.append(("slug", slug))

        if tag_id is not None:
            _query_params.append(("tagId", tag_id))

        if user_id is not None:
            _query_params.append(("userId", user_id))

        if visibility is not None:
            _query_params.append(("visibility", visibility.value))

        if with_coordinates is not None:
            _query_params.append(("withCoordinates", with_coordinates))

        if with_partners is not None:
            _query_params.append(("withPartners", with_partners))

        if with_stacked is not None:
            _query_params.append(("withStacked", with_stacked))

        # process the header parameters
        # process the form parameters
        # process the body parameter

        # set the HTTP header `Accept`
        if "Accept" not in _header_params:
            _header_params["Accept"] = self.api_client.select_header_accept(
                ["application/json"]
            )

        # authentication setting
        _auth_settings: List[str] = ["cookie", "api_key", "bearer"]

        return self.api_client.param_serialize(
            method="GET",
            resource_path="/timeline/buckets",
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth,
        )



# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from immich.client.models.plugin_context_type import PluginContextType
from typing import Set
from typing_extensions import Self


class PluginFilterResponseDto(BaseModel):
    """
    PluginFilterResponseDto
    """  # noqa: E501

    description: StrictStr
    id: StrictStr
    method_name: StrictStr = Field(alias="methodName")
    plugin_id: StrictStr = Field(alias="pluginId")
    var_schema: Optional[Dict[str, Any]] = Field(alias="schema")
    supported_contexts: List[PluginContextType] = Field(alias="supportedContexts")
    title: StrictStr
    __properties: ClassVar[List[str]] = [
        "description",
        "id",
        "methodName",
        "pluginId",
        "schema",
        "supportedContexts",
        "title",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PluginFilterResponseDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if var_schema (nullable) is None
        # and model_fields_set contains the field
        if self.var_schema is None and "var_schema" in self.model_fields_set:
            _dict["schema"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PluginFilterResponseDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "description": obj.get("description"),
                "id": obj.get("id"),
                "methodName": obj.get("methodName"),
                "pluginId": obj.get("pluginId"),
                "schema": obj.get("schema"),
                "supportedContexts": obj.get("supportedContexts"),
                "title": obj.get("title"),
            }
        )
        return _obj



# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class AssetJobName(str, Enum):
    """
    AssetJobName
    """

    """
    allowed enum values
    """
    REFRESH_MINUS_FACES = "refresh-faces"
    REFRESH_MINUS_METADATA = "refresh-metadata"
    REGENERATE_MINUS_THUMBNAIL = "regenerate-thumbnail"
    TRANSCODE_MINUS_VIDEO = "transcode-video"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of AssetJobName from a JSON string"""
        return cls(json.loads(json_str))



# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from uuid import UUID
from immich.client.models.person_response_dto import PersonResponseDto
from immich.client.models.source_type import SourceType
from typing import Set
from typing_extensions import Self


class AssetFaceResponseDto(BaseModel):
    """
    AssetFaceResponseDto
    """  # noqa: E501

    bounding_box_x1: StrictInt = Field(alias="boundingBoxX1")
    bounding_box_x2: StrictInt = Field(alias="boundingBoxX2")
    bounding_box_y1: StrictInt = Field(alias="boundingBoxY1")
    bounding_box_y2: StrictInt = Field(alias="boundingBoxY2")
    id: UUID
    image_height: StrictInt = Field(alias="imageHeight")
    image_width: StrictInt = Field(alias="imageWidth")
    person: Optional[PersonResponseDto]
    source_type: Optional[SourceType] = Field(default=None, alias="sourceType")
    __properties: ClassVar[List[str]] = [
        "boundingBoxX1",
        "boundingBoxX2",
        "boundingBoxY1",
        "boundingBoxY2",
        "id",
        "imageHeight",
        "imageWidth",
        "person",
        "sourceType",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AssetFaceResponseDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of person
        if self.person:
            _dict["person"] = self.person.to_dict()
        # set to None if person (nullable) is None
        # and model_fields_set contains the field
        if self.person is None and "person" in self.model_fields_set:
            _dict["person"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AssetFaceResponseDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "boundingBoxX1": obj.get("boundingBoxX1"),
                "boundingBoxX2": obj.get("boundingBoxX2"),
                "boundingBoxY1": obj.get("boundingBoxY1"),
                "boundingBoxY2": obj.get("boundingBoxY2"),
                "id": obj.get("id"),
                "imageHeight": obj.get("imageHeight"),
                "imageWidth": obj.get("imageWidth"),
                "person": PersonResponseDto.from_dict(obj["person"])
                if obj.get("person") is not None
                else None,
                "sourceType": obj.get("sourceType"),
            }
        )
        return _obj



# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Set
from typing_extensions import Self


class SessionCreateResponseDto(BaseModel):
    """
    SessionCreateResponseDto
    """  # noqa: E501

    app_version: Optional[StrictStr] = Field(alias="appVersion")
    created_at: StrictStr = Field(alias="createdAt")
    current: StrictBool
    device_os: StrictStr = Field(alias="deviceOS")
    device_type: StrictStr = Field(alias="deviceType")
    expires_at: Optional[StrictStr] = Field(default=None, alias="expiresAt")
    id: StrictStr
    is_pending_sync_reset: StrictBool = Field(alias="isPendingSyncReset")
    token: StrictStr
    updated_at: StrictStr = Field(alias="updatedAt")
    __properties: ClassVar[List[str]] = [
        "appVersion",
        "createdAt",
        "current",
        "deviceOS",
        "deviceType",
        "expiresAt",
        "id",
        "isPendingSyncReset",
        "token",
        "updatedAt",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SessionCreateResponseDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if app_version (nullable) is None
        # and model_fields_set contains the field
        if self.app_version is None and "app_version" in self.model_fields_set:
            _dict["appVersion"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SessionCreateResponseDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "appVersion": obj.get("appVersion"),
                "createdAt": obj.get("createdAt"),
                "current": obj.get("current"),
                "deviceOS": obj.get("deviceOS"),
                "deviceType": obj.get("deviceType"),
                "expiresAt": obj.get("expiresAt"),
                "id": obj.get("id"),
                "isPendingSyncReset": obj.get("isPendingSyncReset"),
                "token": obj.get("token"),
                "updatedAt": obj.get("updatedAt"),
            }
        )
        return _obj



# coding: utf-8

"""
Immich

Immich API

The version of the OpenAPI document: 2.4.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from immich.client.models.album_user_response_dto import AlbumUserResponseDto
from immich.client.models.asset_order import AssetOrder
from immich.client.models.asset_response_dto import AssetResponseDto
from immich.client.models.contributor_count_response_dto import (
    ContributorCountResponseDto,
)
from immich.client.models.user_response_dto import UserResponseDto
from typing import Set
from typing_extensions import Self


class AlbumResponseDto(BaseModel):
    """
    AlbumResponseDto
    """  # noqa: E501

    album_name: StrictStr = Field(alias="albumName")
    album_thumbnail_asset_id: Optional[StrictStr] = Field(alias="albumThumbnailAssetId")
    album_users: List[AlbumUserResponseDto] = Field(alias="albumUsers")
    asset_count: StrictInt = Field(alias="assetCount")
    assets: List[AssetResponseDto]
    contributor_counts: Optional[List[ContributorCountResponseDto]] = Field(
        default=None, alias="contributorCounts"
    )
    created_at: datetime = Field(alias="createdAt")
    description: StrictStr
    end_date: Optional[datetime] = Field(default=None, alias="endDate")
    has_shared_link: StrictBool = Field(alias="hasSharedLink")
    id: StrictStr
    is_activity_enabled: StrictBool = Field(alias="isActivityEnabled")
    last_modified_asset_timestamp: Optional[datetime] = Field(
        default=None, alias="lastModifiedAssetTimestamp"
    )
    order: Optional[AssetOrder] = None
    owner: UserResponseDto
    owner_id: StrictStr = Field(alias="ownerId")
    shared: StrictBool
    start_date: Optional[datetime] = Field(default=None, alias="startDate")
    updated_at: datetime = Field(alias="updatedAt")
    __properties: ClassVar[List[str]] = [
        "albumName",
        "albumThumbnailAssetId",
        "albumUsers",
        "assetCount",
        "assets",
        "contributorCounts",
        "createdAt",
        "description",
        "endDate",
        "hasSharedLink",
        "id",
        "isActivityEnabled",
        "lastModifiedAssetTimestamp",
        "order",
        "owner",
        "ownerId",
        "shared",
        "startDate",
        "updatedAt",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AlbumResponseDto from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in album_users (list)
        _items = []
        if self.album_users:
            for _item_album_users in self.album_users:
                if _item_album_users:
                    _items.append(_item_album_users.to_dict())
            _dict["albumUsers"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in assets (list)
        _items = []
        if self.assets:
            for _item_assets in self.assets:
                if _item_assets:
                    _items.append(_item_assets.to_dict())
            _dict["assets"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in contributor_counts (list)
        _items = []
        if self.contributor_counts:
            for _item_contributor_counts in self.contributor_counts:
                if _item_contributor_counts:
                    _items.append(_item_contributor_counts.to_dict())
            _dict["contributorCounts"] = _items
        # override the default output from pydantic by calling `to_dict()` of owner
        if self.owner:
            _dict["owner"] = self.owner.to_dict()
        # set to None if album_thumbnail_asset_id (nullable) is None
        # and model_fields_set contains the field
        if (
            self.album_thumbnail_asset_id is None
            and "album_thumbnail_asset_id" in self.model_fields_set
        ):
            _dict["albumThumbnailAssetId"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AlbumResponseDto from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "albumName": obj.get("albumName"),
                "albumThumbnailAssetId": obj.get("albumThumbnailAssetId"),
                "albumUsers": [
                    AlbumUserResponseDto.from_dict(_item) for _item in obj["albumUsers"]
                ]
                if obj.get("albumUsers") is not None
                else None,
                "assetCount": obj.get("assetCount"),
                "assets": [AssetResponseDto.from_dict(_item) for _item in obj["assets"]]
                if obj.get("assets") is not None
                else None,
                "contributorCounts": [
                    ContributorCountResponseDto.from_dict(_item)
                    for _item in obj["contributorCounts"]
                ]
                if obj.get("contributorCounts") is not None
                else None,
                "createdAt": obj.get("createdAt"),
                "description": obj.get("description"),
                "endDate": obj.get("endDate"),
                "hasSharedLink": obj.get("hasSharedLink"),
                "id": obj.get("id"),
                "isActivityEnabled": obj.get("isActivityEnabled"),
                "lastModifiedAssetTimestamp": obj.get("lastModifiedAssetTimestamp"),
                "order": obj.get("order"),
                "owner": UserResponseDto.from_dict(obj["owner"])
                if obj.get("owner") is not None
                else None,
                "ownerId": obj.get("ownerId"),
                "shared": obj.get("shared"),
                "startDate": obj.get("startDate"),
                "updatedAt": obj.get("updatedAt"),
            }
        )
        return _obj
